@@ -23,7 +23,7 @@
 #include <gtkmm/aboutdialog.h>
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/toolbutton.h>
-#include <libintl.h>
+#include <glibmm/i18n-lib.h>
 #include <algorithm>
 #include <iostream>
 
@@ -244,7 +244,7 @@ void App_Gtk::init_menus_file()
 
   //Build actions:
   m_refFileActionGroup = ActionGroup::create("BakeryFileActions");
-  m_refFileActionGroup->add(Action::create("BakeryAction_Menu_File", "_File"));
+  m_refFileActionGroup->add(Action::create("BakeryAction_Menu_File", _("File")));
 
   m_refFileActionGroup->add(Action::create("BakeryAction_File_New", Gtk::Stock::NEW),
                         sigc::mem_fun((Bakery::App&)*this, &App_Gtk::on_menu_file_new));
@@ -287,7 +287,7 @@ void App_Gtk::init_menus_edit()
   
   //Build actions:
   m_refEditActionGroup = ActionGroup::create("BakeryEditActions");
-  m_refEditActionGroup->add(Action::create("BakeryAction_Menu_Edit", "_Edit"));
+  m_refEditActionGroup->add(Action::create("BakeryAction_Menu_Edit", _("_Edit")));
   
   m_refEditActionGroup->add(Action::create("BakeryAction_Edit_Cut", Gtk::Stock::CUT));
   m_refEditActionGroup->add(Action::create("BakeryAction_Edit_Copy", Gtk::Stock::COPY));
@@ -330,11 +330,11 @@ void App_Gtk::init_menus_help()
 
   //Build actions:
   m_refHelpActionGroup = ActionGroup::create("BakeryHelpActions");
-  m_refHelpActionGroup->add(Action::create("BakeryAction_Menu_Help", "_Help")); //TODO: Use stock?
+  m_refHelpActionGroup->add(Action::create("BakeryAction_Menu_Help", _("_Help")));
 
   //TODO: Use stock?
   m_refHelpActionGroup->add(Action::create("BakeryAction_Help_About",
-                        gettext("_About"), gettext("About the application")),
+                        _("_About"), _("About the application")),
                         sigc::mem_fun((Bakery::App&)*this, &App::on_menu_help_about));
 
   m_refUIManager->insert_action_group(m_refHelpActionGroup);
