@@ -30,7 +30,7 @@
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/filechooserdialog.h>
 #include <giomm.h>
-#include <libintl.h>
+#include <glibmm/i18n-lib.h>
 
 
 namespace Bakery
@@ -41,7 +41,7 @@ void GtkDialogs::ui_warning(App& app, const Glib::ustring& text, const Glib::ust
   Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
 
 #ifdef BAKERY_MAEMO_ENABLED
-  Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, text, Gtk::Stock::DIALOG_WARNING));
+  Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, text, Gtk::Stock::DIALOG_WARNING);
 #else
   Gtk::MessageDialog dialog(App_Gtk::util_bold_message(text), true /* use markup */, Gtk::MESSAGE_WARNING);
   dialog.set_secondary_text(secondary_text);
@@ -60,9 +60,9 @@ Glib::ustring GtkDialogs::ui_file_select_open(App& app, const Glib::ustring& sta
   Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
 
 #ifdef BAKERY_MAEMO_ENABLED
-  Hildon::FileChooserDialog fileChooser_Open(Gtk::FILE_CHOOSER_ACTION_OPEN));
+  Hildon::FileChooserDialog fileChooser_Open(Gtk::FILE_CHOOSER_ACTION_OPEN);
 #else
-  Gtk::FileChooserDialog fileChooser_Open(gettext("Open Document"), Gtk::FILE_CHOOSER_ACTION_OPEN);
+  Gtk::FileChooserDialog fileChooser_Open(_("Open Document"), Gtk::FILE_CHOOSER_ACTION_OPEN);
   fileChooser_Open.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
   fileChooser_Open.add_button(Gtk::Stock::OPEN, Gtk::RESPONSE_OK);
   fileChooser_Open.set_default_response(Gtk::RESPONSE_OK);
@@ -122,7 +122,7 @@ Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old
 #ifdef BAKERY_MAEMO_ENABLED
   Hildon::FileChooserDialog fileChooser_Save(Gtk::FILE_CHOOSER_ACTION_SAVE);
 #else
-  Gtk::FileChooserDialog fileChooser_Save(gettext("Save Document"), Gtk::FILE_CHOOSER_ACTION_SAVE);
+  Gtk::FileChooserDialog fileChooser_Save(_("Save Document"), Gtk::FILE_CHOOSER_ACTION_SAVE);
   fileChooser_Save.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
   fileChooser_Save.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_OK);
   fileChooser_Save.set_default_response(Gtk::RESPONSE_OK);
@@ -185,7 +185,7 @@ Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old
         if(!uri_is_writable(gio_file))
         {
            //Warn the user:
-           ui_warning(app, gettext("Read-only File."), gettext("You may not overwrite the existing file, because you do not have sufficient access rights."));
+           ui_warning(app, _("Read-only File."), _("You may not overwrite the existing file, because you do not have sufficient access rights."));
            try_again = true; //Try again.
            continue;
         }
@@ -199,7 +199,7 @@ Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old
         if(!uri_is_writable(gio_file_parent))
         {
           //Warn the user:
-           ui_warning(app, gettext("Read-only Directory."), gettext("You may not create a file in this directory, because you do not have sufficient access rights."));
+           ui_warning(app, _("Read-only Directory."), _("You may not create a file in this directory, because you do not have sufficient access rights."));
            try_again = true; //Try again.
            continue;
         }
