@@ -18,6 +18,7 @@
  
 #include <bakery/init.h>
 #include <gconfmm.h>
+#include <giomm.h>
 #include <libglademm.h>
 
 namespace Bakery
@@ -26,6 +27,7 @@ namespace Bakery
 void init()
 {
   Gnome::Conf::init();
+  Gio::init();
   //Gnome::Glade::init();
 }
 
