@@ -19,9 +19,9 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <libintl.h>
-
+#include "config.h"
 #include "appexample.h"
+#include <glibmm/i18n.h>
 
 AppExample::AppExample()
   : Bakery::App_WithDoc_Gtk("Bakery_Example_XML")
@@ -36,7 +36,7 @@ void AppExample::init()
 {
   type_vecStrings vecAuthors;
   vecAuthors.push_back("Murray Cumming <murrayc@usa.net>");
-  set_about_information("1.0.0", vecAuthors, "(C) 2000 Murray Cumming", gettext("A Bakery XML example."));
+  set_about_information("1.0.0", vecAuthors, "(C) 2000 Murray Cumming", _("A Bakery XML example."));
 
   //Call base method:
   Bakery::App_WithDoc_Gtk::init();
